@@ -1,4 +1,4 @@
-/* $Id: expense.c,v 1.41 2005/10/25 06:47:30 rikster5 Exp $ */
+/* $Id: expense.c,v 1.52 2007/06/06 02:45:10 rikster5 Exp $ */
 
 /*******************************************************************************
  * expense.c
@@ -177,7 +177,6 @@ static int show_category;
 static int glob_category_number_from_menu_item[MAX_CATEGORY2];
 
 static int record_changed;
-static int clist_hack;
 static int clist_row_selected;
 static int connected=0;
 
@@ -200,8 +199,9 @@ static void cb_clist_selection(GtkWidget      *clist,
                                gpointer       data);
 static void cb_add_new_record(GtkWidget *widget, gpointer data);
 static void cb_pulldown_menu(GtkWidget *item, unsigned int value);
-static int make_menu(char *items[], int menu_index, GtkWidget **Poption_menu,
+static int  make_menu(char *items[], int menu_index, GtkWidget **Poption_menu,
                      GtkWidget *menu_items[]);
+static int  expense_find(int unique_id);
 
 /******************************************************************************/
 /* Start of code                                                              */
@@ -278,48 +278,32 @@ static void set_new_button_to(int new_state)
 
    switch (new_state) {
     case MODIFY_FLAG:
-      gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_SINGLE);
-      clist_hack=TRUE;
-      /* The line selected on the clist becomes unhighlighted, so we do this */
-      gtk_clist_select_row(GTK_CLIST(clist), clist_row_selected, 0);
+      gtk_widget_show(copy_record_button);
       gtk_widget_show(apply_record_button);
+
+      gtk_widget_hide(add_record_button);
       gtk_widget_hide(delete_record_button);
+      gtk_widget_hide(new_record_button);
       break;
     case NEW_FLAG:
-      gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_SINGLE);
-      clist_hack=TRUE;
-      /* The line selected on the clist becomes unhighlighted, so we do this */
-      gtk_clist_select_row(GTK_CLIST(clist), clist_row_selected, 0);
       gtk_widget_show(add_record_button);
+
+      gtk_widget_hide(apply_record_button);
       gtk_widget_hide(copy_record_button);
       gtk_widget_hide(delete_record_button);
+      gtk_widget_hide(new_record_button);
       break;
     case CLEAR_FLAG:
-      gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_BROWSE);
-      clist_hack=FALSE;
-      gtk_widget_show(new_record_button);
-      gtk_widget_show(copy_record_button);
       gtk_widget_show(delete_record_button);
+      gtk_widget_show(copy_record_button);
+      gtk_widget_show(new_record_button);
+
+      gtk_widget_hide(add_record_button);
+      gtk_widget_hide(apply_record_button);
       break;
     default:
       return;
    }
-   switch (record_changed) {
-    case MODIFY_FLAG:
-      gtk_widget_hide(apply_record_button);
-      gtk_widget_show(copy_record_button);
-      gtk_widget_show(delete_record_button);
-      break;
-    case NEW_FLAG:
-      gtk_widget_hide(add_record_button);
-      gtk_widget_show(copy_record_button);
-      gtk_widget_show(delete_record_button);
-      break;
-    case CLEAR_FLAG:
-      gtk_widget_hide(new_record_button);
-      gtk_widget_hide(delete_record_button);
-      break;
-   }
    record_changed=new_state;
 }
 
@@ -594,35 +578,6 @@ static char *get_entry_type(enum ExpenseType type)
    }
 }
 
-#ifdef JPILOT_DEBUG
-/*
- * A utility function for getting textual data from an enum.
- */
-static char *get_pay_type(enum ExpensePayment type)
-{
-   switch (type) {
-    case epAmEx:
-      return _("AmEx");
-    case epCash:
-      return _("Cash");
-    case epCheck:
-      return _("Check");
-    case epCreditCard:
-      return _("CreditCard");
-    case epMasterCard:
-      return _("MasterCard");
-    case epPrepaid:
-      return _("Prepaid");
-    case epVISA:
-      return _("VISA");
-    case epUnfiled:
-      return _("Unfiled");
-    default:
-      return NULL;
-   }
-}
-#endif
-
 /* This function gets called when the "delete" button is pressed */
 static void cb_delete(GtkWidget *widget, gpointer data)
 {
@@ -976,11 +931,6 @@ static void display_records()
    if (-1 == num)
      return;
 
-   /* Go to first entry in the list */
-   for (temp_list = records; temp_list; temp_list = temp_list->prev) {
-      records = temp_list;
-   }
-
    entries_shown = 0;
    for (i=0, temp_list = records; temp_list; temp_list = temp_list->next, i++) {
       if (temp_list->data) {
@@ -1163,23 +1113,30 @@ static void cb_clist_selection(GtkWidget      *clist,
 {
    struct MyExpense *mexp;
    int i, item_num, category;
-   int keep, b;
+   int b;
    int currency_position;
+   unsigned int unique_id = 0;
 
    jp_logf(JP_LOG_DEBUG, "Expense: cb_clist_selection\n");
 
-   if ((!event) && (clist_hack)) return;
+   if ((record_changed==MODIFY_FLAG) || (record_changed==NEW_FLAG)) {
+      mexp = gtk_clist_get_row_data(GTK_CLIST(clist), row);
+      if (mexp!=NULL) {
+	 unique_id = mexp->unique_id;
+      }
 
-   /* HACK, see clist hack explanation in memo_gui.c */
-   if (clist_hack) {
-      keep=record_changed;
-      gtk_clist_select_row(GTK_CLIST(clist), clist_row_selected, column);
       b=dialog_save_changed_record(scrolled_window, record_changed);
-      if (b==DIALOG_SAID_1) {
+      if (b==DIALOG_SAID_2) {
          cb_add_new_record(NULL, GINT_TO_POINTER(record_changed));
       }
       set_new_button_to(CLEAR_FLAG);
-      gtk_clist_select_row(GTK_CLIST(clist), row, column);
+
+      if (unique_id)
+      {
+         expense_find(unique_id);
+      } else {
+	 clist_select_row(GTK_CLIST(clist), row, column);
+      }
       return;
    }
    
@@ -1308,7 +1265,7 @@ static void cb_pulldown_menu(GtkWidget *item, unsigned int value)
    switch (menu) {
     case EXPENSE_CAT1:
       b=dialog_save_changed_record(scrolled_window, record_changed);
-      if (b==DIALOG_SAID_1) {
+      if (b==DIALOG_SAID_2) {
          cb_add_new_record(NULL, GINT_TO_POINTER(record_changed));
       }
    
@@ -1620,7 +1577,7 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
    
    /* Clist */
    clist = gtk_clist_new(3);
-   clist_hack=FALSE;
+
    /* gtk_clist_set_shadow_type(GTK_CLIST(clist), SHADOW);*/
    gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_BROWSE);
    gtk_clist_set_column_width(GTK_CLIST(clist), 0, 50);
@@ -1639,7 +1596,7 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
    /************************************************************/
    /* Right half of screen */
 
-   hbox_temp = gtk_hbox_new(FALSE, 0);
+   hbox_temp = gtk_hbox_new(FALSE, 3);
    gtk_box_pack_start(GTK_BOX(vbox2), hbox_temp, FALSE, FALSE, 0);
 
    /* Delete, Copy, New, etc. buttons */
@@ -1914,7 +1871,7 @@ int plugin_gui_cleanup() {
    jp_logf(JP_LOG_DEBUG, "Expense: plugin_gui_cleanup\n");
 
    b=dialog_save_changed_record(scrolled_window, record_changed);
-   if (b==DIALOG_SAID_1) {
+   if (b==DIALOG_SAID_2) {
       cb_add_new_record(NULL, GINT_TO_POINTER(record_changed));
    }
 
@@ -2023,11 +1980,6 @@ int plugin_search(const char *search_string, int case_sense, struct search_resul
    if (-1 == num)
      return 0;
 
-   /* Go to first entry in the list */
-   for (temp_list = records; temp_list; temp_list = temp_list->prev) {
-      records = temp_list;
-   }
-   
    count = 0;
    
    for (temp_list = records; temp_list; temp_list = temp_list->next) {
@@ -2096,7 +2048,7 @@ int plugin_help(char **text, int *width, int *height)
            "Expense plugin for J-Pilot was written by\n"
            "Judd Montgomery (c) 1999.\n"
            "judd@jpilot.org\n"
-           "http://jpilot.org\n"
+           "http://jpilot.org"
            );
    *height = 0;
    *width = 0;
