@@ -1,4 +1,7 @@
-/* synctime.c
+/* $Id: synctime.c,v 1.11 2006/09/28 22:01:37 rikster5 Exp $ */
+
+/*******************************************************************************
+ * synctime.c
  *
  * Copyright (C) 1999 by Judd Montgomery
  *
@@ -15,7 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -25,6 +29,8 @@
 #include <pi-source.h>
 #include "libplugin.h"
 
+#include "../i18n.h"
+
 void plugin_version(int *major_version, int *minor_version)
 {
    *major_version=0;
@@ -39,7 +45,7 @@ int plugin_get_name(char *name, int len)
 
 int plugin_get_help_name(char *name, int len)
 {
-   strncpy(name, "About SyncTime", len);
+   g_snprintf(name, len, _("About %s"), _("SyncTime"));
    return 0;
 }
 
@@ -52,7 +58,8 @@ int plugin_help(char **text, int *width, int *height)
 	   "Judd Montgomery (c) 1999.\n"
 	   "judd@jpilot.org\n"
 	   "http://jpilot.org\n"
-	   "SyncTime WILL NOT work with PalmOS 3.3!\n"
+	   "\n"
+	   "SyncTime WILL NOT work with PalmOS 3.3!"
 	   );
    *height = 0;
    *width = 0;
@@ -78,18 +85,18 @@ int plugin_sync(int sd)
 
    if (majorVersion==3) {
       if ((minorVersion==30) || (minorVersion==25)) {
-	 jp_logf(JP_LOG_GUI, "synctime: Palm OS Version 3.25 and 3.30 do not support SyncTime\n");
-	 jp_logf(JP_LOG_GUI, "synctime: NOT setting the time on the pilot\n");
+	 jp_logf(JP_LOG_GUI, _("synctime: Palm OS Version 3.25 and 3.30 do not support SyncTime\n"));
+	 jp_logf(JP_LOG_GUI, _("synctime: NOT setting the time on the pilot\n"));
 	 return 1;
       }
    }
 
-   jp_logf(JP_LOG_GUI, "synctime: Setting the time on the pilot... ");
+   jp_logf(JP_LOG_GUI, _("synctime: Setting the time on the pilot... "));
    
    time(&ltime);
    r = dlp_SetSysDateTime(sd, ltime);
    
-   jp_logf(JP_LOG_GUI, "Done\n");
+   jp_logf(JP_LOG_GUI, _("Done\n"));
 
    return 0;
 }
