@@ -1,4 +1,7 @@
-/* address.h
+/* $Id: address.h,v 1.10 2006/07/21 22:25:24 rikster5 Exp $ */
+
+/*******************************************************************************
+ * address.h
  * A module of J-Pilot http://jpilot.org
  * 
  * Copyright (C) 1999-2002 by Judd Montgomery
@@ -15,20 +18,19 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
+
 #ifndef __ADDRESS_H__
 #define __ADDRESS_H__
 
 #include <pi-address.h>
 #include "utils.h"
 
-/* This flag will force sorting other than on the palm
- * 0 on palm: by lastname, first
- * 1 on palm: by company
- * 0 will sort same as on palm
- * 1 will reverse it
+/* This flag affects sorting of address records
+ * 0 : by lastname, first
+ * 1 : by company name
  */
-extern int sort_override;
+extern int sort_by_company;
 
 int get_address_app_info(struct AddressAppInfo *aai);
 int pc_address_write(struct Address *a, PCRecType rt, unsigned char attrib,
