@@ -1,4 +1,4 @@
-/* $Id: address_gui.c,v 1.126 2006/09/26 22:51:57 rikster5 Exp $ */
+/* $Id: address_gui.c,v 1.131 2007-08-11 19:29:29 rousseau Exp $ */
 
 /*******************************************************************************
  * address_gui.c
@@ -39,6 +39,7 @@
 #include "export.h"
 #include <pi-dlp.h>
 #include "stock_buttons.h"
+#include "otherconv.h"
 
 /* There are a large number of calls to gtk_text_insert in the code.  To
  * add ifdef/endif blocks around all of them would make the code unreadable.
@@ -157,6 +158,9 @@ static void cb_clist_selection(GtkWidget      *clist,
 			       GdkEventButton *event,
 			       gpointer       data);
 
+char *address_app_info_labels[19+3];
+char *address_app_info_phoneLabels[8];
+
 static void init()
 {
    int i, j;
@@ -246,8 +250,9 @@ cb_record_changed(GtkWidget *widget,
    }
    else if (record_changed==UNDELETE_FLAG)
    {
-      jp_logf(JP_LOG_INFO|JP_LOG_GUI, _("This record is deleted.\n"
-	   "Undelete it or copy it to make changes.\n"));
+      jp_logf(JP_LOG_INFO|JP_LOG_GUI, 
+              _("This record is deleted.\n"
+	        "Undelete it or copy it to make changes.\n"));
    }
 }
 
@@ -1763,7 +1768,7 @@ static void cb_clist_selection(GtkWidget      *clist,
 	    if (addr->entry[i2]) {
 	       if (i2>2 && i2<8) {
 		  gtk_text_insert(GTK_TEXT(text), NULL,NULL,NULL,
-				  address_app_info.phoneLabels[addr->phoneLabel[i2-3]], -1);
+				  address_app_info_phoneLabels[addr->phoneLabel[i2-3]], -1);
 	       } else {
 		  gtk_text_insert(GTK_TEXT(text), NULL,NULL,NULL, address_app_info.labels[i2], -1);
 	       }
@@ -1796,11 +1801,23 @@ static void cb_clist_selection(GtkWidget      *clist,
 	 i2=order[i];
 	 if (addr->entry[i2]) {
 	    if (i2>2 && i2<8) {
-	       gtk_text_insert(GTK_TEXT(text), NULL,NULL,NULL,
-			       address_app_info.phoneLabels[addr->phoneLabel[i2-3]],
-			       -1);
+	       char *label = address_app_info_phoneLabels[addr->phoneLabel[i2-3]];
+#ifdef ENABLE_GTK2
+	       label = other_to_UTF(label, strlen(label));
+#endif
+	       gtk_text_insert(GTK_TEXT(text), NULL,NULL,NULL, label, -1);
+#ifdef ENABLE_GTK2
+	       g_free(label);
+#endif
 	    } else {
-	       gtk_text_insert(GTK_TEXT(text), NULL,NULL,NULL, address_app_info.labels[i2], -1);
+	       char *label = address_app_info.labels[i2];
+#ifdef ENABLE_GTK2
+	       label = other_to_UTF(label, strlen(label));
+#endif
+	       gtk_text_insert(GTK_TEXT(text), NULL,NULL,NULL, label, -1);
+#ifdef ENABLE_GTK2
+	       g_free(label);
+#endif
 	    }
 	    gtk_text_insert(GTK_TEXT(text), NULL,NULL,NULL, ": ", -1);
 	    gtk_text_insert(GTK_TEXT(text), NULL,NULL,NULL, addr->entry[i2], -1);
@@ -1893,7 +1910,8 @@ static void cb_clist_selection(GtkWidget      *clist,
 					(menu_item[i][addr->phoneLabel[i]]), TRUE);
 	 gtk_option_menu_set_history(GTK_OPTION_MENU(phone_list_menu[i]),
 				     addr->phoneLabel[i]);
-	 if (!strcmp(address_app_info.labels[addr->phoneLabel[i]+3],_("E-mail"))) {
+         /* E-mail category changes Dial button to Mail button */
+	 if (addr->phoneLabel[i] == 4) {
 #ifdef ENABLE_GTK2
 	    gtk_button_set_label(GTK_BUTTON(dial_button[i]),_("Mail"));
 	    gtk_object_set_data(GTK_OBJECT(dial_button[i]), "mail", GINT_TO_POINTER(1));
@@ -2012,11 +2030,11 @@ static void address_update_clist(GtkWidget *clist, GtkWidget *tooltip_widget,
 
    for (i=0;i<NUM_ADDRESS_LABELS;i++) {
       jp_logf(JP_LOG_DEBUG, "labels[%02d]:",i);
-      print_string(address_app_info.labels[i],16);
+      print_string(address_app_info_labels[i],16);
    }
    for (i=0;i<8;i++) {
       jp_logf(JP_LOG_DEBUG, "phoneLabels[%d]:",i);
-      print_string(address_app_info.phoneLabels[i],16);
+      print_string(address_app_info_phoneLabels[i],16);
    }
    jp_logf(JP_LOG_DEBUG, "country %d\n",address_app_info.country);
    jp_logf(JP_LOG_DEBUG, "sortByCompany %d\n",address_app_info.sortByCompany);
@@ -2249,9 +2267,9 @@ static int make_phone_menu(int default_set, unsigned int callback_id, int set)
    group = NULL;
 
    for (i=0; i<8; i++) {
-      if (address_app_info.phoneLabels[i][0]) {
+      if (address_app_info_phoneLabels[i][0]) {
 	 menu_item[set][i] = gtk_radio_menu_item_new_with_label(
-			group, address_app_info.phoneLabels[i]);
+			group, address_app_info_phoneLabels[i]);
 	 gtk_signal_connect(GTK_OBJECT(menu_item[set][i]), "activate",
 			    GTK_SIGNAL_FUNC(cb_phone_menu),
 			    GINT_TO_POINTER(callback_id + i));
@@ -2538,12 +2556,26 @@ int address_gui(GtkWidget *vbox, GtkWidget *hbox)
    get_address_app_info(&address_app_info);
 
    get_pref(PREF_CHAR_SET, &char_set, NULL);
+   /* Convert to host character set */
    for (i=0; i<NUM_ADDRESS_CAT_ITEMS; i++) {
       cat_name = charset_p2newj(address_app_info.category.name[i], 31, char_set);
       strcpy(sort_l[i].Pcat, cat_name);
       free(cat_name);
       sort_l[i].cat_num=i;
    }
+   for (i = 0; i < 19 + 3; i++)
+      if (address_app_info.labels[i][0] != '\0') {
+	 address_app_info_labels[i] = (char_set != CHAR_SET_LATIN1) ? charset_p2newj(address_app_info.labels[i],16, char_set) : address_app_info.labels[i];
+      }
+      else
+	 address_app_info_labels[i] = "";
+   for (i = 0; i < 8; i++)
+      if (address_app_info.phoneLabels[i][0] != '\0') {
+	 address_app_info_phoneLabels[i] = (char_set != CHAR_SET_LATIN1) ? charset_p2newj(address_app_info.phoneLabels[i],16, char_set) : address_app_info.phoneLabels[i];
+      }
+      else
+	 address_app_info_phoneLabels[i] = "";
+
    qsort(sort_l, NUM_ADDRESS_CAT_ITEMS, sizeof(struct sorted_cats), cat_compare);
 #ifdef JPILOT_DEBUG
    for (i=0; i<NUM_ADDRESS_CAT_ITEMS; i++) {
@@ -2788,7 +2820,7 @@ int address_gui(GtkWidget *vbox, GtkWidget *hbox)
 	 if (i2>2 && i2<8) {
 	    make_phone_menu(i2-3, (i2-3)<<4, i2-3);
 	 } else if (i2 < NUM_ADDRESS_ENTRIES) {
-	    label = gtk_label_new(address_app_info.labels[i2]);
+	    label = gtk_label_new(address_app_info_labels[i2]);
 	    /*gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT); */
 	    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
 	 } else {
@@ -2883,7 +2915,7 @@ int address_gui(GtkWidget *vbox, GtkWidget *hbox)
 	 if (i2>2 && i2<8) {
 	    make_phone_menu(i2-3, (i2-3)<<4, i2-3);
 	 } else {
-	    label = gtk_label_new(address_app_info.labels[i2]);
+	    label = gtk_label_new(address_app_info_labels[i2]);
 	    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
 	 }
 #ifdef ENABLE_GTK2
@@ -2903,13 +2935,8 @@ int address_gui(GtkWidget *vbox, GtkWidget *hbox)
 	    if (i2>2 && i2<8) {
 	       gtk_table_attach(GTK_TABLE(table1), GTK_WIDGET(phone_list_menu[i2-3]),
 				2, 3, i, i+1, GTK_SHRINK, 0, 0, 0);
-	       if (!strcmp(address_app_info.labels[i2], _("E-mail"))) {
-		  dial_button[i2-3] = gtk_button_new_with_label(_("Mail"));
-		  gtk_object_set_data(GTK_OBJECT(dial_button[i2-3]), "mail", GINT_TO_POINTER(1));
-	       } else {
-		  dial_button[i2-3] = gtk_button_new_with_label(_("Dial"));
-		  gtk_object_set_data(GTK_OBJECT(dial_button[i2-3]), "mail", 0);
-	       }
+               dial_button[i2-3] = gtk_button_new_with_label(_("Dial"));
+               gtk_object_set_data(GTK_OBJECT(dial_button[i2-3]), "mail", 0);
 	       gtk_signal_connect(GTK_OBJECT(dial_button[i2-3]), "clicked",
 				  GTK_SIGNAL_FUNC(cb_dial_or_mail),
 			          address_text[i2]);
