@@ -1,4 +1,4 @@
-/* $Id: jpilot.c,v 1.143 2006/11/11 02:08:59 rikster5 Exp $ */
+/* $Id: jpilot.c,v 1.145 2007/06/06 02:45:09 rikster5 Exp $ */
 
 /*******************************************************************************
  * jpilot.c
@@ -1501,10 +1501,6 @@ const char *user_icon[] = {
    }
 
 #ifdef ENABLE_PLUGINS
-   /* Go to first entry in the list */
-   for (temp_list = plugin_list; temp_list; temp_list = temp_list->prev)
-      plugin_list = temp_list;
-
    /* Count the plugin/ entries */
    for (count=0, temp_list = plugin_list;
 	temp_list; temp_list = temp_list->next) {
@@ -2538,7 +2534,7 @@ char * xpm_backup[] = {
    /* Make the output text window */
    temp_hbox = gtk_hbox_new(FALSE, 0);
    gtk_container_set_border_width(GTK_CONTAINER(temp_hbox), 5);
-   gtk_paned_pack2(GTK_PANED(output_pane), temp_hbox, TRUE, TRUE);
+   gtk_paned_pack2(GTK_PANED(output_pane), temp_hbox, FALSE, TRUE);
 
    temp_vbox = gtk_vbox_new(FALSE, 3);
    gtk_container_set_border_width(GTK_CONTAINER(temp_vbox), 6);
