@@ -1,4 +1,4 @@
-/* $Id: prefs.c,v 1.65 2006/02/14 20:53:26 rikster5 Exp $ */
+/* $Id: prefs.c,v 1.67 2007-08-07 16:03:06 rikster5 Exp $ */
 
 /*******************************************************************************
  * prefs.c
@@ -132,6 +132,8 @@ static prefType glob_prefs[NUM_PREFS] = {
      {"datebook_anni_years", INTTYPE, INTTYPE, 0, NULL, 0},
      {"keyring_pane", INTTYPE, INTTYPE, 0, NULL, 0},
      {"expense_pane", INTTYPE, INTTYPE, 0, NULL, 0},
+     {"todo_sort_column", INTTYPE, INTTYPE, 1, NULL, 0},
+     {"todo_sort_order", INTTYPE, INTTYPE, 0, NULL, 0},
 };
 
 struct name_list {
@@ -173,7 +175,7 @@ void pref_init()
 	 glob_prefs[i].svalue_size=strlen(glob_prefs[i].svalue)+1;
 	 break;
        case PREF_MAIL_COMMAND:
-	 glob_prefs[i].svalue=strdup("mozilla -remote \"mailto(\%s)\"");
+	 glob_prefs[i].svalue=strdup("mozilla-thunderbird -remote \"mailto(\%s)\"");
 	 glob_prefs[i].svalue_size=strlen(glob_prefs[i].svalue)+1;
 	 break;
        default:
