@@ -1,4 +1,4 @@
-/* $Id: prefs.h,v 1.41 2005/10/07 19:30:59 rousseau Exp $ */
+/* $Id: prefs.h,v 1.43 2007/06/05 19:39:48 rikster5 Exp $ */
 
 /*******************************************************************************
  * prefs.h
@@ -111,8 +111,10 @@
 #define PREF_DATEBOOK_ANNI_YEARS 83
 #define PREF_KEYRING_PANE 84
 #define PREF_EXPENSE_PANE 85
+#define PREF_TODO_SORT_COLUMN 86
+#define PREF_TODO_SORT_ORDER 87
 
-#define NUM_PREFS 86
+#define NUM_PREFS 88
 
 #define MAX_PREF_NUM_BACKUPS 99
 
@@ -134,7 +136,8 @@
 #define CHAR_SET_SJIS_UTF 14 /* Japanese (SJIS) */
 #define CHAR_SET_1255_UTF 15 /* Hebrew (CP1255) */
 #define CHAR_SET_BIG5_UTF 16 /* Chinese (BIG-5) */
-#define NUM_CHAR_SETS    17
+#define CHAR_SET_949_UTF 17 /* Korean (CP949) */
+#define NUM_CHAR_SETS    18
 
 #define MAX_PREF_VALUE 200
 
