@@ -1,4 +1,4 @@
-/* $Id: todo.c,v 1.40 2005/12/18 15:05:40 rousseau Exp $ */
+/* $Id: todo.c,v 1.42 2007/06/06 02:45:10 rikster5 Exp $ */
 
 /*******************************************************************************
  * todo.c
@@ -244,14 +244,12 @@ void pc_todo_validate_correct(struct ToDo *todo)
 {
    if (todo->description) {
       if ((strlen(todo->description)+1 > MAX_TODO_DESC_LEN)) {
-	 jp_logf(JP_LOG_WARN, "%s\n", todo->description);
 	 jp_logf(JP_LOG_WARN, _("ToDo description text > %d, truncating to %d\n"), MAX_TODO_DESC_LEN, MAX_TODO_DESC_LEN-1);
 	 todo->description[MAX_TODO_DESC_LEN-1]='\0';
       }
    }
    if (todo->note) {
       if ((strlen(todo->note)+1 > MAX_TODO_NOTE_LEN)) {
-	 jp_logf(JP_LOG_WARN, "%s\n", todo->note);
 	 jp_logf(JP_LOG_WARN, _("ToDo note text > %d, truncating to %d\n"), MAX_TODO_NOTE_LEN, MAX_TODO_NOTE_LEN-1);
 	 todo->note[MAX_TODO_NOTE_LEN-1]='\0';
       }
@@ -466,10 +464,7 @@ int get_todos2(ToDoList **todo_list, int sort_order,
    if (-1 == num)
       return 0;
 #endif
-   /* Go to first entry in the list */
-   for (temp_list = records; temp_list; temp_list = temp_list->prev) {
-      records = temp_list;
-   }
+
    for (i=0, temp_list = records; temp_list; temp_list = temp_list->next, i++) {
       if (temp_list->data) {
 	 br=temp_list->data;
