@@ -1,4 +1,4 @@
-/* $Id: utils.h,v 1.52 2005/10/24 19:15:41 judd Exp $ */
+/* $Id: utils.h,v 1.56 2006/07/30 13:51:46 rousseau Exp $ */
 
 /*******************************************************************************
  * utils.h
@@ -106,6 +106,11 @@
 #define DIALOG_SAID_IMPORT_SKIP 457
 #define DIALOG_SAID_IMPORT_QUIT 458
 
+#define DIALOG_INFO     1
+#define DIALOG_QUESTION 2
+#define DIALOG_ERROR    3
+#define DIALOG_WARNING  4
+
 #define CAL_DONE   100
 #define CAL_CANCEL 101
 
@@ -231,6 +236,8 @@ void fprint_usage_string(FILE *out);
 
 int cat_compare(const void *v1, const void *v2);
 
+int get_timeout_interval();
+
 gint timeout_date(gpointer data);
 
 int get_pixmaps(GtkWidget *widget,
@@ -254,7 +261,7 @@ int get_home_file_name(char *file, char *full_name, int max_size);
 
 FILE *jp_open_home_file(char *filename, char *mode);
 
-int raw_header_to_header(RawDBHeader *rdbh, DBHeader *dbh);
+int unpack_db_header(DBHeader *dbh, unsigned char *buffer);
 
 int find_next_offset(mem_rec_header *mem_rh, long fpos,
 		     unsigned int *next_offset,
@@ -286,16 +293,9 @@ int setup_sync(unsigned int flags);
 void cb_sync(GtkWidget *widget, unsigned int flags);
 void get_compile_options(char *string, int len);
 
-int dialog_generic_with_text(GtkWindow *main_window,
-			     int w, int h,
-			     char *title, char *frame_text,
-			     char *text, int nob, char *button_text[],
-			     int with_text);
-
 /* Returns the number of the button that was pressed */
 int dialog_generic(GtkWindow *main_window,
-		   int w, int h,
-		   char *title, char *frame_text,
+		   char *title, int type,
 		   char *text, int nob, char *button_text[]);
 
 /*
@@ -304,7 +304,7 @@ int dialog_generic(GtkWindow *main_window,
  * This just calls dialog_generic with an OK button.
  */
 int dialog_generic_ok(GtkWidget *widget,
-		      char *title, char *frame_text, char *text);
+		      char *title, int type, char *text);
 
 /*
  * Widget must be some widget used to get the main window from.
@@ -574,4 +574,7 @@ char *charset_p2newj(const char *buf, int max_len, int char_set);
 
 void jp_charset_p2j(char *buf, int max_len);
 size_t jp_strftime(char *s, size_t max, const char *format, const struct tm *tm);
+#ifndef ENABLE_GTK2
+size_t g_strlcpy(char *dst, const char *src, size_t siz);
+#endif
 #endif
